# Qingping IoT APIs

## Auth

OAuth 2.0 is used as per [https://developer.qingping.co/cloud-to-cloud/oauth](https://developer.qingping.co/cloud-to-cloud/oauth). 

## Open APIs

For reference, see [Qingping IoT API docs](https://developer.qingping.co/cloud-to-cloud/).

### Implemented

- Auth (token retrieval)
- Device List (actually includes current sensor readings and device details)

### In-progress

### Planned

- Device History Data
- Device History Event
- Device Settings Modification

### Not planned

- Device Binding
- Device Unbinding
- Group List
- Device Profile
